==> haskell-witherable-0.4.2-223-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-IaKW4QXhRdCHPK0JW5h9mi
key:                  witherable-0.4.2-IaKW4QXhRdCHPK0JW5h9mi
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  f9e7763cd922aa0d44b727d6f1233989
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-IaKW4QXhRdCHPK0JW5h9mi
depends:
    base-4.17.2.1 base-orphans-0.9.3-FaXRPq0OvzpGLQLZkGVInM
    containers-0.6.7 hashable-1.4.7.0-LvsgkXc0RJl9ehxeji9DTo
    indexed-traversable-0.1.4-2BJBYQqmGPr8tnVTwezaGL
    indexed-traversable-instances-0.1.2-69rcWKqbuLOFPjXO3MOiMa
    transformers-0.5.6.2
    unordered-containers-0.2.20.1-LlrDkEbe6ka5Vid8Nf7fMl
    vector-0.13.2.0-9W9rHKyBrY08EKASla5WO0

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-witherable-0.4.2-224-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-CaHTbZ0uHXzzLWHqJucQ
key:                  witherable-0.4.2-CaHTbZ0uHXzzLWHqJucQ
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  89945fea62812d2bce9051b7ad84bbb5
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-CaHTbZ0uHXzzLWHqJucQ
depends:
    base-4.17.2.1 base-orphans-0.9.3-EJowifzJFrc7UkPlEad70r
    containers-0.6.7 hashable-1.4.7.0-bh6X3bZPF56LQTYQ27khw
    indexed-traversable-0.1.4-2jca0tWP54e6sSfMY1ZadX
    indexed-traversable-instances-0.1.2-JVCk0wPlofoDzDyutnFscS
    transformers-0.5.6.2
    unordered-containers-0.2.20.1-98Hg6PuNW0XDqLHXL1727Z
    vector-0.13.2.0-24VaMY7coOLw3wI0c1W3K

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
